import 'dart:async';
import 'location_entity.dart';
import 'plugin_controller.dart';

abstract class AmapsLocation {
  ///
  /// 获取一个单例
  ///
  static AmapsLocation? create() {
    return AmapsLocationImpl.getInstance();
  }

  ///
  /// 获取GPS定位
  /// [apiKey]        高德地图官方apiKey
  ///
  Future<LocationEntity> getLocation({String? apiKey});

  ///
  /// 是否打开GPS
  ///
  Future<bool?> isOpenGPS();

  ///
  /// 启用手机GPS
  ///
  Future<bool?> enableGPS();
}

class AmapsLocationImpl extends AmapsLocation {
  AmapsController _amapsController;

  AmapsLocationImpl._() : _amapsController = PluginControllerFactory().create();

  static AmapsLocationImpl? _instance;

  static AmapsLocationImpl? getInstance() {
    if (_instance == null) {
      _instance = AmapsLocationImpl._();
    }
    return _instance;
  }

  @override
  Future<bool?> enableGPS() async {
    return _amapsController.enableGPS();
  }

  @override
  Future<bool?> isOpenGPS() async {
    return _amapsController.isOpenGPS();
  }

  @override
  Future<LocationEntity> getLocation({String? apiKey}) {
    return _amapsController.getLocation(apiKey: apiKey);
  }
}
